package com.theitbulls.contextmenuex;

import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.appcompat.view.menu.MenuPopupHelper;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.appcompat.widget.PopupMenu;
import androidx.core.view.GravityCompat;
import androidx.recyclerview.widget.RecyclerView;

import java.lang.reflect.Field;

public class PopupMenuAdapter extends RecyclerView.Adapter {
    private final String[] items;

    public PopupMenuAdapter(String[] items) {
        this.items = items;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.list_view_item, parent, false);
        return new MyViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder holder, final int position) {
        final MyViewHolder viewHolder = (MyViewHolder) holder;

        viewHolder.tvName.setText(items[position]);
        viewHolder.tvMnu.setOnClickListener(new MyClickListner(position));
    }

    @Override
    public int getItemCount() {
        return items.length;
    }

    @Override
    public void onViewRecycled(RecyclerView.ViewHolder holder) {
        holder.itemView.setOnLongClickListener(null);
        super.onViewRecycled(holder);
    }

    public class MyViewHolder extends RecyclerView.ViewHolder {
        public final AppCompatTextView tvName;
        public final AppCompatTextView tvMnu;

        public View itemView;

        public MyViewHolder(@NonNull View itemView) {
            super(itemView);

            tvName = itemView.findViewById(R.id.tvName);
            tvMnu = itemView.findViewById(R.id.tvMnu);
            this.itemView = itemView;
        }
    }

    private class MyClickListner implements View.OnClickListener {
        private int position;

        public MyClickListner(int position) {
            this.position = position;
        }

        @Override
        public void onClick(final View view) {
            PopupMenu popup = new PopupMenu(view.getContext(), view);

            popup.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
                @Override
                public boolean onMenuItemClick(MenuItem item) {
                    switch (item.getItemId()) {
                        case R.id.ctxMnuCopy:
                            Toast.makeText(view.getContext(), "You select Copy for: " + items[position], Toast.LENGTH_SHORT).show();
                            return true;
                        case R.id.ctxMnuPaste:
                            Toast.makeText(view.getContext(), "You select Paste for: " + items[position], Toast.LENGTH_SHORT).show();
                            return true;
                        case R.id.ctxMnuDelete:
                            Toast.makeText(view.getContext(), "You select Delete for: " + items[position], Toast.LENGTH_SHORT).show();
                            return true;
                    }
                    return false;
                }
            });
            // here you can inflate your menu
            popup.inflate(R.menu.context_menu);
            popup.setGravity(GravityCompat.RELATIVE_HORIZONTAL_GRAVITY_MASK);

            // if you want icon with menu items then write this try-catch block.
            try {
                Field mFieldPopup = popup.getClass().getDeclaredField("mPopup");
                mFieldPopup.setAccessible(true);
                MenuPopupHelper mPopup = (MenuPopupHelper) mFieldPopup.get(popup);
                mPopup.setForceShowIcon(true);
            } catch (Exception e) {

            }
            popup.show();
        }
    }

}
